netapp_ontap.models.security_key_manager_external API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.security_key_manager_external`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class SecurityKeyManagerExternalSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SecurityKeyManagerExternal object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `client_certificate GET POST PATCH`

    The client_certificate field of the security_key_manager_external.

  `server_ca_certificates GET POST PATCH`

    The UUIDs of the server CA certificates already installed in the cluster or SVM. The array of certificates are common for all the keyservers per SVM.

  `servers GET POST PATCH`

    The set of external key servers.